#!/usr/bin/python3

import base64
import unittest
from basic import TestCharm


class TestDualDeployment(TestCharm):
    @classmethod
    def setUpClass(cls):
        # Same setup as the basic test
        super(TestDualDeployment, cls).configure()

        # Add a second log archive deployment
        cls.d.add('cla-anon', charm='container-log-archive')
        cls.d.relate('apache2:juju-info', 'cla-anon:juju-info')

        cls.d.configure('cla-anon', {
            'container_credentials': base64.b64encode(cls.creds.encode('utf-8')).decode('utf-8'),
            'container_name': cls.container_name,
            'container_type': 's3',
            'delete_after_archive': 'false',
            'preprocessors': 'gunzip anonymize_web_log gzip',
            'logdirs': '{} {}'.format(cls.log_dir1, cls.log_dir2),
        })

        # Call setup again to add the second charm
        cls.d.setup(timeout=900)
        cls.d.sentry.wait()

        cls.cla = cls.d.sentry['log-archive'][0]
        cls.cla_anon = cls.d.sentry['cla-anon'][0]

    def test_anon_deployment(self):
        cla_files = ['/etc/cron.d/cla-cla-anon',
                     '/etc/sudoers.d/15-cla-anon',
                     '/home/log-archive/cla-anon.rc',
                     ]

        # Verify each file exists by doing a stat
        for path in cla_files:
            self.cla_anon.file_stat(path)


if __name__ == "__main__":
    unittest.main()
